@@ -6,14 +6,19 @@
 // http://opensource.org/licenses/MIT>, at your option. This file may not be
 // copied, modified, or distributed except according to those terms.
 
+use std::path::Path;
+use std::thread::sleep;
+use std::time::Duration;
+
 use staart::TailedFile;
 
 fn main() -> Result<(), Box<dyn std::error::Error>> {
+    const DEFAULT_DELAY: Duration = Duration::from_millis(100);
     let args: Vec<String> = std::env::args().collect();
-    let path = &args[1].as_str();
+    let path = Path::new(&args[1]);
     let mut f = TailedFile::new(path)?;
     loop {
         f.follow()?;
-        f.sleep();
+        sleep(DEFAULT_DELAY);
     }
 }
